/*
 * MSPM0L_Driver.h
 *
 *  Created on: Jan 27, 2022
 *      Author: a0224173
 */

#ifndef DRIVER_MSPM0LXX_DRIVER_H_
#define DRIVER_MSPM0LXX_DRIVER_H_


#include <ti/devices/msp/msp.h>
#include <ti/driverlib/driverlib.h>
#include <ti/driverlib/m0p/dl_core.h>
#include <ti/iqmath/include/IQmathLib.h>




#define COMP_INST_DACCODE0                                                   (0)
#define OPA_GAIN                                                             (32)
/* Default value */
#define POWER_STARTUP_DELAY                                                 (16)
#define NTC_SHIFT                                                          (-40)
#define NTC_TABLE_LENGTH                                                     (126)

/* GPIO configuration for USER_LED_1 */
#define GPIO_CHG_PIN                                             (DL_GPIO_PIN_13)
#define GPIO_CHG_IOMUX                                            (IOMUX_PINCM14)
#define GPIO_DHG_PIN                                             (DL_GPIO_PIN_14)
#define GPIO_DHG_IOMUX                                            (IOMUX_PINCM15)
#define GPIO_LED2_PIN                                             (DL_GPIO_PIN_27)
#define GPIO_LED2_IOMUX                                            (IOMUX_PINCM28)
#define GPIO_LED1_PIN                                             (DL_GPIO_PIN_25)
#define GPIO_LED1_IOMUX                                            (IOMUX_PINCM26)
#define GPIO_LED4_PIN                                             (DL_GPIO_PIN_5)
#define GPIO_LED4_IOMUX                                            (IOMUX_PINCM6)
#define GPIO_LED3_PIN                                             (DL_GPIO_PIN_4)
#define GPIO_LED3_IOMUX                                            (IOMUX_PINCM5)
#define GPIO_OPA_IN0POS_PIN                                     (DL_GPIO_PIN_18)
#define GPIO_OPA_IN0POS_IOMUX                                    (IOMUX_PINCM19)
#define GPIO_OPA_OUT_PIN                                        (DL_GPIO_PIN_16)
#define GPIO_OPA_OUT_IOMUX                                    (IOMUX_PINCM17)
#define GPIO_REF_PIN                                          (DL_GPIO_PIN_22)
#define GPIO_REF_IOMUX                                         (IOMUX_PINCM23)

/* GPIO configuration for USER_SWITCH_1 */
#define GPIO_SWITCHES_INT_IRQN                                  (GPIOA_INT_IRQn)
#define GPIO_SWITCHES_INT_IIDX                  (DL_INTERRUPT_GROUP1_IIDX_GPIOA)
#define GPIO_SWITCHES_USER_SWITCH_1_PIN                         (DL_GPIO_PIN_12)
#define GPIO_SWITCHES_USER_SWITCH_1_IOMUX                        (IOMUX_PINCM13)

/* Definitions for ADC */
#define ADC12_INST                                                        (ADC0)
#define ADC12_INST_IRQHandler                                    ADC0_IRQHandler
#define ADC12_INST_INT_IRQN                                      (ADC0_INT_IRQn)
#define GPIO_ADC12_C2_PORT                                               (GPIOA)
#define GPIO_ADC12_C2_PIN                                       (DL_GPIO_PIN_25)
#define GPIO_IOMUX_ADC12_C2                                      (IOMUX_PINCM26)
#define GPIO_IOMUX_ADC12_C2_FUNCTION              (IOMUX_PINCM26_PF_UNCONNECTED)

/* Definitions for UART */
#define UART_OVERSAMPLING_32_KHZ_9600_BAUD        (DL_UART_OVERSAMPLING_RATE_3X)
#define UART_IBRD_32_MHZ_115200_BAUD                                        (17)
#define UART_FBRD_32_MHZ_115200_BAUD                                        (23)
#define GPIO_UART1_TX_PIN                                         (DL_GPIO_PIN_0)
#define GPIO_UART1_IOMUX_TX                                        (IOMUX_PINCM1)
#define GPIO_UART1_IOMUX_TX_FUNCTION                 (IOMUX_PINCM1_PF_UART1_TX)
#define GPIO_UART1_RX_PIN                                         (DL_GPIO_PIN_1)
#define GPIO_UART1_IOMUX_RX                                       (IOMUX_PINCM2)
#define GPIO_UART1_IOMUX_RX_FUNCTION               (IOMUX_PINCM2_PF_UART1_RX)

#define GPIO_UART0_TX_PIN                                         (DL_GPIO_PIN_8)
#define GPIO_UART0_IOMUX_TX                                        (IOMUX_PINCM9)
#define GPIO_UART0_IOMUX_TX_FUNCTION                 (IOMUX_PINCM9_PF_UART0_TX)
#define GPIO_UART0_RX_PIN                                         (DL_GPIO_PIN_9)
#define GPIO_UART0_IOMUX_RX                                       (IOMUX_PINCM10)
#define GPIO_UART0_IOMUX_RX_FUNCTION               (IOMUX_PINCM10_PF_UART0_RX)

/* Definitions for I2C */
#define I2C_INST                                                          (I2C0)
#define I2C_INST_IRQHandler                                      I2C0_IRQHandler
#define I2C_INST_INT_IRQN                                        (I2C0_INT_IRQn)
#define GPIO_IOMUX_I2C_SDA                                        (IOMUX_PINCM1)
#define GPIO_IOMUX_I2C_SDA_FUNCTION                   (IOMUX_PINCM1_PF_I2C0_SDA)
#define GPIO_IOMUX_I2C_SCL                                        (IOMUX_PINCM2)
#define GPIO_IOMUX_I2C_SCL_FUNCTION                   (IOMUX_PINCM2_PF_I2C0_SCL)

/* Definitions for TIMERG */
#define TIMER_INST                                                      (TIMG0)
#define TIMER_INST_IRQHandler                                  TIMG0_IRQHandler
#define TIMER_INST_INT_IRQN                                    (TIMG0_INT_IRQn)

/* Definitions for ADC */
#define DMA_CH0_SEL                                                          (0)
#define ADC12_INST                                                        (ADC0)
#define ADC12_INST_IRQHandler                                    ADC0_IRQHandler

/* clang-format on */
void SYSCFG_DL_initPower(void);
void Driver_TempMeassure(void);
void Driver_BattVoltMeassure(void);
void Driver_GpioInit(void);
void Driver_Uart1Init(void);
void Driver_Uart0Init(void);
void Driver_DACBufferSet(void);
void Driver_DiffAmpSet(void);
void  Driver_DetectionPowerEnable(void);
void Driver_DetectionPowerDisable(void);
void Driver_VrefInit(void);
_iq5 Driver_ADCInitAndSampling(uint32_t adcChannel, uint32_t vrefSource, _iq5 adcOffset);
void Driver_DACInit(uint32_t u32DacValue);
void Driver_OPA0Init(void);
void Driver_OPA1Init(uint32_t u32Gain);
void Driver_Uart1TxU16Data(uint16_t u16Data);
void Driver_TimerInit(void);
#endif /* DRIVER_MSPM0LXX_DRIVER_H_ */
